@@ -34,7 +34,7 @@ import threading
 import time
 from functools import reduce
 
-import ifaddr
+import ifcfg
 from six import binary_type, indexbytes, int2byte, iteritems, text_type
 from six.moves import xrange
 
@@ -42,7 +42,7 @@ import enum_compat as enum
 
 __author__ = "Paul Scott-Murphy, William McBrine"
 __maintainer__ = "Jamie Alexandre <jamie@learningequality.org>"
-__version__ = "0.19.6"
+__version__ = "0.19.9"
 __license__ = "LGPL"
 
 
@@ -1707,6 +1707,7 @@ class ZeroconfServiceTypes(object):
 
 
 if "ANDROID_ARGUMENT" in os.environ:
+
     from jnius import autoclass
 
     AndroidString = autoclass("java.lang.String")
@@ -1729,20 +1730,18 @@ if "ANDROID_ARGUMENT" in os.environ:
                     else:
                         interfaces.append({"inet": "", "inet6": address})
         except Exception as e:
-            raise e
+            return []
 
         return interfaces
 
+
 else:
-     def get_network_interfaces():
-         interfaces = []
-         for adapter in ifaddr.get_adapters():
-             for ip in adapter.ips:
-                 interfaces.append({
-                     "inet": ip.ip if ip.is_IPv4 else "",
-                     "inet6": ip.ip if ip.is_IPv6 else ""
-                 })
-         return interfaces
+
+    def get_network_interfaces():
+        try:
+            return ifcfg.interfaces().values()
+        except:  # ifcfg throws an Exception if the ip/ifconfig commands are not found
+            return []
 
 
 def get_all_addresses():
@@ -1812,7 +1811,7 @@ class Zeroconf(QuietLogger):
         :type interfaces: :class:`InterfaceChoice` or sequence of ip addresses
         """
         # hook for threads
-        self._GLOBAL_DONE = False
+        self._GLOBAL_DONE = threading.Event()
 
         self._listen_socket = new_socket()
         interfaces = normalize_interface_choice(interfaces)
@@ -1869,7 +1868,7 @@ class Zeroconf(QuietLogger):
 
     @property
     def done(self):
-        return self._GLOBAL_DONE
+        return self._GLOBAL_DONE.wait(0.1)
 
     def wait(self, timeout):
         """Calling thread waits for a given number of milliseconds or
@@ -2278,7 +2277,7 @@ class Zeroconf(QuietLogger):
             return
         log.debug("Sending %r (%d bytes) as %r...", out, len(packet), packet)
         for s in self._respond_sockets:
-            if self._GLOBAL_DONE:
+            if self._GLOBAL_DONE.is_set():
                 return
             try:
                 outgoing_ip = s.getsockopt(socket.IPPROTO_IP, socket.IP_MULTICAST_IF, 4)
@@ -2299,11 +2298,11 @@ class Zeroconf(QuietLogger):
     def close(self):
         """Ends the background threads, and prevent this instance from
         servicing further queries."""
-        if not self._GLOBAL_DONE:
+        if not self._GLOBAL_DONE.is_set():
             # remove service listeners
             self.remove_all_service_listeners()
             self.unregister_all_services()
-            self._GLOBAL_DONE = True
+            self._GLOBAL_DONE.set()
 
             # shutdown recv socket and thread
             self.engine.del_reader(self._listen_socket)
